@@ -5,6 +5,7 @@
  * Copyright (c) 2011 Philippe Pepiot <phil@philpep.org>
  * Copyright (c) 2011-2012 Marin Atanasov Nikolov <dnaeon@gmail.com>
  * Copyright (c) 2013-2014 Matthew Seaman <matthew@FreeBSD.org>
+ * Copyright (c) 2014-2016 Vsevolod Stakhov <vsevolod@FreeBSD.org>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -43,7 +44,6 @@ extern "C" {
 #include <stdarg.h>
 #include <stdbool.h>
 #include <stdio.h>
-#include <sysexits.h>
 
 /* The expected name of the pkg(8) binary executable. */
 #ifndef PKG_EXEC_NAME
@@ -55,12 +55,12 @@ extern "C" {
 #define PKG_STATIC_NAME	"pkg-static"
 #endif
 
-#define PKGVERSION "1.9.99.4"
+#define PKGVERSION "1.10.99.7"
 
 /* PORTVERSION equivalent for proper pkg-static->ports-mgmt/pkg
  * version comparison in pkgdb_query_newpkgversion() */
 
-#define PKG_PORTVERSION "1.9.99.4"
+#define PKG_PORTVERSION "1.10.99.7"
 
 /* The OS major version at the time of compilation */
 #ifdef __FreeBSD__
@@ -118,7 +118,7 @@ typedef void * pkg_iter;
 struct pkg_kv {
 	char *key;
 	char *value;
-	struct pkg_kv *next;
+	struct pkg_kv *next, *prev;
 };
 
 /**
@@ -370,7 +370,8 @@ typedef enum _pkg_flags {
 	PKG_FLAG_FORCE_MISSING = (1U << 9),
 	PKG_FLAG_FETCH_MIRROR = (1U << 10),
 	PKG_FLAG_USE_IPV4 = (1U << 11),
-	PKG_FLAG_USE_IPV6 = (1U << 12)
+	PKG_FLAG_USE_IPV6 = (1U << 12),
+	PKG_FLAG_UPGRADE_VULNERABLE = (1U << 13)
 } pkg_flags;
 
 typedef enum _pkg_stats_t {
@@ -809,7 +810,7 @@ int pkg_is_installed(struct pkgdb *db, const char *name);
  */
 typedef int(pkg_password_cb)(char *, int, int, void*);
 int pkg_create_repo(char *path, const char *output_dir, bool filelist,
-	const char *metafile, bool legacy);
+	const char *metafile);
 int pkg_finish_repo(const char *output_dir, pkg_password_cb *cb, char **argv,
     int argc, bool filelist);
 
@@ -1067,6 +1068,19 @@ int pkg_jobs_cudf_emit_file(struct pkg_jobs *, pkg_jobs_t , FILE *);
  */
 int pkg_jobs_cudf_parse_output(struct pkg_jobs *j, FILE *f);
 
+/**
+ * Check if there are locked packages
+ * @return true if locked packages exist, false if not
+ */
+bool pkg_jobs_has_lockedpkgs(struct pkg_jobs *j);
+
+/**
+ * Iterate through the locked packages, calling the passed in function pointer
+ * on each.
+ */
+typedef int(*locked_pkgs_cb)(struct pkg *, void *);
+void pkg_jobs_iter_lockedpkgs(struct pkg_jobs *j, locked_pkgs_cb, void *);
+
 /**
  * Solve a SAT problem
  * @return true if a problem is solvable
@@ -1127,7 +1141,7 @@ int pkg_create_from_manifest(const char *, pkg_formats, const char *,
 /**
  * Create package from stage install with a metadata directory
  */
-int pkg_create_staged(const char *, pkg_formats, const char *, const char *, char *);
+int pkg_create_staged(const char *, pkg_formats, const char *, const char *, char *, bool);
 int pkg_load_metadata(struct pkg *, const char *, const char *, const char *, const char *, bool);
 
 /**
@@ -1215,11 +1229,6 @@ int pkg_repo_cached_name(struct pkg *pkg, char *dest, size_t destlen);
 /* glue to deal with ports */
 int ports_parse_plist(struct pkg *, const char *, const char *);
 
-/**
- * @todo Document
- */
-int pkg_copy_tree(struct pkg *, const char *src, const char *dest);
-
 /**
  * Special structure to report about conflicts
  */
@@ -1480,16 +1489,7 @@ int pkg_test_filesum(struct pkg *);
 int pkg_recompute(struct pkgdb *, struct pkg *);
 int pkgdb_reanalyse_shlibs(struct pkgdb *, struct pkg *);
 
-#ifdef __DragonFly__
-#define pkg_get_myarch(d, z) pkg_get_myarch_legacy(d, z)
-#else
-int pkg_get_myarch(char *pkgarch, size_t sz);
-#endif
-int pkg_get_myarch_legacy(char *pkgarch, size_t sz);
-
 void pkgdb_cmd(int argc, char **argv);
-int pkg_old_load_from_path(struct pkg *pkg, const char *path);
-int pkg_from_old(struct pkg *pkg);
 int pkg_sshserve(int fd);
 
 int pkg_repos_total_count(void);
